local fs = require "nixio.fs" 

m = Map("modbus_to_ftp", translate("Modbus to FTP"))

s = m:section(TypedSection, "modbus_ftp", translate("Configuration"))
s.anonymous = true
s.addremove = false

enabled = s:option(Flag, "enabled", "Enable", translate("Enable Modbus to FTP"))
enabled.default = "0"
enabled.rmempty = false

local_file_path = s:option(Value, "local_file_path", translate("Local File Path"),
        translate("Path to store files locally before they are uploaded to server"))
local_file_path.default = "/root/data/modbus"

--protocol
protocol = s:option(ListValue, "protocol", translate("Protocol"),
        translate("Protocol that is being used."))
protocol:value("ftp", translate("FTP"))
protocol:value("sftp", translate("SFTP"))
protocol:value("scp", translate("SCP"))

--host
host = s:option(Value, "host", translate("Host IP Address"), translate("IP address or host name of the server to upload the data files"))
host.datatype = "host"

--port
port = s:option(Value, "port", translate("Port"), translate("Default port number for FTP is 21, SCP is 22"))
port.datatype = "port"
port.default = "21"

--remote path
remote_path = s:option(Value, "remote_path", translate("Remote Path"), translate("Folder path on the remote server to upload the files"))
remote_path.datatype = "string"

username = s:option(Value, "username", translate("Username"))
username.datatype = "maxlength(128)"

pass = s:option(Value, "pass", translate("Password"))
pass.password = true

--upload_interval
upload_interval = s:option(Value, "upload_interval", translate("Upload Interval (Seconds)"))
upload_interval.datatype = "range(1,86400)"

--file_creation_interval
file_creation_interval = s:option(Value, "file_creation_interval", translate("File Creation Interval (Seconds)"))
file_creation_interval.datatype = "range(1,86400)"

return m
